@@ -35,12 +35,18 @@
 #include "libxnee/xnee_replay.h"
 #include "libxnee/datastrings.h"
 #include "libxnee/xnee_threshold.h"
-#include "parse.h"
+#include "libxnee/xnee_strings.h"
 #include "libxnee/print.h"
 #include "libxnee/xnee_range.h"
 #include "libxnee/xnee_error.h"
 #include "libxnee/xnee_keysym.h"
 #include "libxnee/feedback.h"
+#include "libxnee/xnee_session.h"
+#include "libxnee/xnee_plugin.h"
+#include "libxnee/xnee_display.h"
+#include "libxnee/xnee_utils.h"
+
+#include "parse.h"
 
 
 
@@ -157,6 +163,8 @@ xnee_parse_args (xnee_data* xd , int argc, char **argv )
 
   int i ;
   int ret=0;
+  #define XNEE_PARSE_BUF 200
+  char buf [XNEE_PARSE_BUF]; 
  
   for (i = 1; i < argc; i++) 
     {
@@ -316,7 +324,6 @@ xnee_parse_args (xnee_data* xd , int argc, char **argv )
 	  ret = xnee_set_rc_byname (xd, argv[i]);
 	  if ( ret != XNEE_OK) 
 	    {
-	      char buf [200]; 
 	      xnee_verbose((xd, "Could not open project file %s\n", argv[i]));
 	      
 	      if ( (strlen(argv[i]) + strlen (XNEE_RESOURCE_DIR) + 2 ) > 200)
@@ -326,9 +333,9 @@ xnee_parse_args (xnee_data* xd , int argc, char **argv )
 		  xnee_close_down(xd);
 		  exit(XNEE_WRONG_PARAMS);
 		}
-	      strcpy ( buf , XNEE_RESOURCE_DIR);
-	      strcat ( buf , "/");
-	      strcat ( buf , argv[i]);
+	      strncpy ( buf , XNEE_RESOURCE_DIR, XNEE_PARSE_BUF );
+	      strncat ( buf ,  "/", XNEE_PARSE_BUF - strlen(buf));
+	      strncat ( buf , argv[i], XNEE_PARSE_BUF - strlen(buf));
 	      xnee_verbose((xd, "\ttryingresource file %s\n", buf));
 	      ret = xnee_set_rc_name (xd, buf);
 	    }
@@ -994,7 +1001,7 @@ xnee_manpage (FILE *fd)
   fprintf (fd ,"Henrik Sandklef.\n");
 
   fprintf (fd ,".SH \"REPORTING BUGS\"\n");
-  fprintf (fd ,"Report bugs in the program to "XNEE_BUG_MAIL". \n");
+  fprintf (fd ,"Report bugs in the program to %s. \n", XNEE_BUG_MAIL);
 
   fprintf (fd ,".SH \"COPYRIGHT\"\n");
   fprintf (fd ,"Copyright (C) 2002 Henrik Sandklef.\n");
@@ -1011,7 +1018,7 @@ xnee_manpage (FILE *fd)
   fprintf (fd ,".SH \"NOTES\"\n");
   fprintf (fd ,"This page describes\n");
   fprintf (fd ,".B Xnee.\n");
-  fprintf (fd ,"Mail corrections and additions to " XNEE_BUG_MAIL "\n");
+  fprintf (fd ,"Mail corrections and additions to %s\n", XNEE_BUG_MAIL );
 }
 
 int
@@ -1020,7 +1027,9 @@ xnee_type_help (xnee_data *xd)
   int i ;
   xnee_script_s xss ;
 
-  char my_string[500];
+  #define HELP_STR_SIZE 500
+
+  char my_string[HELP_STR_SIZE];
   char **cpp;
 
   xnee_verbose ((xd,"---> xnee_type_help\n"));
@@ -1033,7 +1042,7 @@ xnee_type_help (xnee_data *xd)
   for (cpp = help; *cpp; cpp+=1) 
     {
       xnee_verbose ((xd,"string to fake %s\n", *cpp));
-      strcpy(my_string,*cpp);
+      strncpy(my_string,*cpp,HELP_STR_SIZE);
 
       for (i=0;(size_t)i<strlen(my_string);i++)
 	{
