@@ -29,59 +29,194 @@
 #include "libxnee/xnee_replay.h"
 
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * @param disp  name of the X display to set
+ * 
+ * This functions is called to set the display name of the 
+ * main display for Xnee.
+ *
+ * @return      0 on success
+ */
 int
-xnee_set_display_name (xnee_data *xd, char *disp);
+xnee_set_display_name (xnee_data *xd, const char *disp);
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * This functions is called to get the display name of the
+ * display used in Xnee.
+ *
+ * @return      display
+ */
 char*
 xnee_get_display_name (xnee_data *xd);
 
+
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * This functions is called to get the display of the 
+ * control display for Xnee.
+ *
+ * @return 
+ */
 Display *
 xnee_get_control_display(xnee_data *xd);
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * This functions is called to get the display of the 
+ * data display for Xnee.
+ *
+ * @return 
+ */
 Display *
 xnee_get_data_display(xnee_data *xd);
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * This functions is called to get the display of the 
+ * grab display for Xnee.
+ *
+ * @return      display 
+ */
 Display *
 xnee_get_grab_display(xnee_data *xd);
 
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * @param out   file descriptor to use for printout
+ * 
+ * @return 
+ */
 int
 xnee_set_out_file (xnee_data *xd, FILE* out);
 
+
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * @return      file descriptor to use for printout
+ */
 FILE*
 xnee_get_out_file (xnee_data *xd);
 
+/** 
+ * 
+ * 
+ * @param xd         xnee's main structure
+ * @param out_name   file name to use for printout
+ * 
+ * @return 
+ */
 int
 xnee_set_out_name (xnee_data *xd, char* out_name);
  
+/** 
+ * 
+ * 
+ * @param xd         xnee's main structure
+ * 
+ * @return           file name to use for printout
+ */
 char *
 xnee_get_out_name (xnee_data *xd);
 
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * @param rt    file descriptor to use for retype
+ * 
+ * @return 
+ */
 int
 xnee_set_rt_file (xnee_data *xd, FILE* rt);
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * @return      file descriptor to use for retype
+ */
 FILE*
 xnee_get_rt_file (xnee_data *xd);
 
+/** 
+ * 
+ * 
+ * @param xd         xnee's main structure
+ * 
+ * @return           file name to use for retype
+ */
 int
 xnee_set_rt_name (xnee_data *xd, char* rt_name);
  
+/** 
+ * 
+ * 
+ * @param xd         xnee's main structure
+ * 
+ * @return           file name to use for retype
+ */
 char *
 xnee_get_rt_name (xnee_data *xd);
 
 
+/** 
+ * 
+ * 
+ * @param xd        xnee's main structure
+ * @param err       file decriptor to use for error prints
+ * 
+ * @return          0 on success
+ */
 int
 xnee_set_err_file (xnee_data *xd, FILE* err);
 
+/** 
+ * 
+ * 
+ * @param xd    xnee's main structure
+ * 
+ * @return      file descriptor to use for error prints
+ */
 FILE*
 xnee_get_err_file (xnee_data *xd);
 
 
-
+/** 
+ * 
+ * 
+ * @param xd         xnee's main structure
+ * @param out_name   file name to use for error prints
+ * 
+ * @return           0 on success
+ */
 int
 xnee_set_err_name (xnee_data *xd, char* err_name);
  
+
 char *
 xnee_get_err_name (xnee_data *xd);
 
@@ -94,10 +229,10 @@ xnee_get_rc_file (xnee_data *xd);
 
 
 int
-xnee_set_rc_name (xnee_data *xd, char* rc_name);
+xnee_set_rc_name (xnee_data *xd, const char* rc_name);
  
 int
-xnee_set_rc_byname (xnee_data *xd, char* rc_name);
+xnee_set_rc_byname (xnee_data *xd, const char* rc_name);
  
  
 char *
@@ -112,7 +247,7 @@ FILE*
 xnee_get_data_file (xnee_data *xd);
 
 int
-xnee_set_data_name (xnee_data *xd, char* data);
+xnee_set_data_name (xnee_data *xd, const char* data);
 
 char *
 xnee_get_data_name (xnee_data *xd);
@@ -199,7 +334,7 @@ char*
 xnee_get_exec_prog (xnee_data *xd);
 
 int
-xnee_set_key (xnee_data *xd, int mode, char* key );
+xnee_set_key (xnee_data *xd, int mode, const char* key );
 
 char *
 xnee_get_key (xnee_data *xd, int mode);
@@ -211,13 +346,13 @@ char*
 xnee_get_extra_str (xnee_data *xd, int idx);
 
 int
-xnee_set_key_str (xnee_data *xd, int idx, char *str);
+xnee_set_key_str (xnee_data *xd, int idx, const char *str);
 
 int
-xnee_set_extra_str (xnee_data *xd, int idx, char *str);
+xnee_set_extra_str (xnee_data *xd, int idx, const char *str);
 
 int
-xnee_set_exec_prog (xnee_data *xd, char *prog);
+xnee_set_exec_prog (xnee_data *xd, const char *prog);
 
 
 #define xnee_get_stop_key(xd)        xnee_get_key_str(xd, XNEE_GRAB_STOP)
@@ -337,7 +472,7 @@ xnee_set_xnee_printout (xnee_data *xd);
 #define xnee_is_xnee_printout(xd)  (xd->rec_callback == xnee_record_dispatch)
 
 int
-xnee_set_replay_speed_str (xnee_data *xd, char *speed_str);
+xnee_set_replay_speed_str (xnee_data *xd, const char *speed_str);
 
 int
 xnee_set_replay_speed (xnee_data *xd, int speed);
@@ -394,7 +529,7 @@ Bool
 xnee_is_store_mouse_pos(xnee_data *xd);
 
 int
-xnee_set_program_name(xnee_data *xd, char* name);
+xnee_set_program_name(xnee_data *xd, const char* name);
 
 char *
 xnee_get_program_name(xnee_data *xd);
@@ -409,4 +544,17 @@ int
 xnee_unset_new_project(xnee_data *xd);
 
 
+int
+xnee_set_autorepeat (xnee_data *xd);
+
+int
+xnee_reset_autorepeat (xnee_data *xd);
+
+
+int
+xnee_set_application_parameters(xnee_data *xd, char **argv);
+
+char **
+xnee_get_application_parameters(xnee_data *xd);
+
 #endif /* XNEE_SETGET_H */ 
