@@ -36,6 +36,8 @@
 #include "libxnee/feedback.h"
 #include "libxnee/xnee_range.h"
 #include "libxnee/xnee_error.h"
+#include "libxnee/xnee_session.h"
+#include "libxnee/xnee_utils.h"
 
 
 #ifdef DEBUG_DISPATCHER
@@ -106,6 +108,8 @@ get_screen_nr(Display *dpy, Window recorded_root)
   /* If we didn't find a screen, bail out */
   if ( this_screen == -1)
     {
+      /* FIX ME FIX ME.... 
+	 this may be intepreted as a screen nr */
       return XNEE_SCREEN_MISSING;
     }
   
@@ -270,7 +274,7 @@ xnee_record_handle_event ( xnee_data *xd, /*@null@*/ XRecordInterceptData *xreci
                  
                  xd->xnee_info.last_motion = True ;
                  ret = xnee_fake_motion_event (xd,
-                                               0, 
+                                               screen, 
                                                xrec_data->event.u.keyButtonPointer.rootX, 
                                                xrec_data->event.u.keyButtonPointer.rootY, 
                                                CurrentTime);
@@ -512,18 +516,18 @@ xnee_record_init (xnee_data *xd)
   xd->xnee_info.first_last      = False  ; /* Intercept all MotionNotify, else only first and last */
 
   xd->xnee_info.last_motion     = False  ; /* Used to record only first and last Motion in a row*/
-  xd->xnee_info.events_recorded = 0    ; /* Default 100 Datum */
+  xd->xnee_info.events_recorded = 0    ; 
   xd->xnee_info.store_mouse_pos = 0;
    
-  xd->xnee_info.data_recorded   = 0    ; /* Default 500 Datum*/
+  xd->xnee_info.data_recorded   = 0    ; 
    
-  xd->xnee_info.time_recorded   = 0      ; /* Default 1*/
+  xd->xnee_info.time_recorded   = 0    ;
    
-  xd->xnee_info.events_max      = 100    ; /* Default 100 Datum */
+  xd->xnee_info.events_max      = -1    ; 
    
-  xd->xnee_info.data_max        = 500    ; /* Default 500 Datum*/
+  xd->xnee_info.data_max        = -1    ; 
    
-  xd->xnee_info.time_max        = 1     ; /* Default 1*/
+  xd->xnee_info.time_max        = -1    ; 
    
   xd->xnee_info.x               = 0      ; /* Need not to be set, anyhow last MotionNotify x=0*/
   xd->xnee_info.y               = 0      ; /* Need not to be set, anyhow last MotionNotify x=0*/
